//=============================================================================
// ShotgunIg50Weapon.
//=============================================================================
class ShotgunIg50Weapon extends CatableWeapon;

#exec OBJ LOAD FILE=Ig50Mesh.usx
#exec OBJ LOAD FILE=MP_Weapons.ukx

///////////////////////////////////////////////////////////////////////////////
// Vars, structs, consts
///////////////////////////////////////////////////////////////////////////////

var float SPAccuracy;				// How accurate we are in single player games.
var ShotgunIg50 TM4;

const BASE_FLASH_OFFSET_X = 0.055;
const BASE_FLASH_OFFSET_Y = 0.01;
const RAND_OFFSET = 0.01;

///////////////////////////////////////////////////////////////////////////////
simulated function PostBeginPlay()
{
	local float diffoffset;

	Super.PostBeginPlay();

	// If it's a single player game, make our accuracy much worse
	if(Level.Game != None
		&& FPSGameInfo(Level.Game).bIsSinglePlayer)
	{
		TraceAccuracy = SPAccuracy;

		// Based on the difficulty, bump up the number of times AI will continuously
		// shoot this weapon
		diffoffset = P2GameInfo(Level.Game).GetDifficultyOffset();
		if(diffoffset > 0)
		{
			AI_BurstCountExtra+=(diffoffset/2);
		}
	}
}

simulated function PostNetBeginPlay()
{
    local PlayerController PC;
	local Pawn P;

    Super.PostNetBeginPlay();

    P  = Pawn(Owner);
	PC = PlayerController(P.Controller);

   	if (P.IsLocallyControlled() && PC!=None && (!PC.bBehindView) )
	{
        TM4 = Spawn(Class'Ig50Inventory.ShotgunIg50');
        AttachToBone( TM4, 'shotgun Ig50' );
    }
   	else
	{
        if(Instigator != None)
	   {
		 if(Instigator.Mesh != None)

             TM4.Destroyed();
             TM4 = None;
	   }
	}

}

///////////////////////////////////////////////////////////////////////////////

function DropFrom(vector StartLocation)
{

   Super.DropFrom(StartLocation);

     TM4.Destroyed();

}

simulated function Destroyed()
{
   Super.Destroyed();

  if( TM4 != None )
  {
    DetachFromBone(TM4);
    TM4.Destroy();
    TM4 = None;
  }
}

///////////////////////////////////////////////////////////////////////////////
// This will randomly change the color and the size of the dynamic
// light associate with the flash. Change in each weapon's file,
// but call each time you start up the flash again.
// This function is also used by the third-person muzzle flash, so the 
// colors will look the same
///////////////////////////////////////////////////////////////////////////////
simulated function PickLightValues()
{
	LightBrightness=150;
	LightSaturation=150;
	LightHue=22+FRand()*10;
	LightRadius=24+FRand()*6;
}

///////////////////////////////////////////////////////////////////////////////
// DrawMuzzleFlash()
//Default implementation assumes that flash texture can be drawn inverted in X and/or Y direction to increase apparent
//number of flash variations
// We might need to draw a dark blood splat
///////////////////////////////////////////////////////////////////////////////
simulated function DrawMuzzleFlash(Canvas Canvas)
{
	local float Scale, ULength, VLength, UStart, VStart;

//	FlashOffsetX = BASE_FLASH_OFFSET_X + FRand()*RAND_OFFSET;
//	FlashOffsetY = BASE_FLASH_OFFSET_Y + FRand()*RAND_OFFSET;

	if(CatOnGun == 0
		|| !class'P2Player'.static.BloodMode())
		Super.DrawMuzzleFlash(Canvas);
	else	// if a cat, then draw it alpha blended with a gross blood splat
	{
		Scale = MuzzleScale * Canvas.ClipX/640.0;
		Canvas.Style = ERenderStyle.STY_Alpha;
		ULength = MFTexture.USize;
		if ( FRand() <= 0.5 )
		{
			UStart = ULength;
			ULength = -1 * ULength;
		}
		VLength = MFTexture.VSize;
		if ( FRand() <= 0.5 )
		{
			VStart = VLength;
			VLength = -1 * VLength;
		}

		Canvas.DrawTile(MFTexture, Scale * MFTexture.USize, Scale * MFTexture.VSize, 
					UStart, VStart, ULength, VLength);
		Canvas.Style = ERenderStyle.STY_Normal;
	}
}

///////////////////////////////////////////////////////////////////////////////
// See what we hit
///////////////////////////////////////////////////////////////////////////////
function TraceFire( float Accuracy, float YOffset, float ZOffset )
{
	local int i;
	
	// Reduce the ammo only by 1 here, for the shotgun, but shoot
	// ShotCountMaxForNotify number of pellets each time.
	P2AmmoInv(AmmoType).UseAmmoForShot();

	// Reduce the cat ammo if we're using one
	if(CatOnGun == 1)
		CatAmmoLeft--;

	for(i=0; i<ShotCountMaxForNotify; i++)
	{
		Super.TraceFire(Accuracy, YOffset, ZOffset);
	}
}
state ClientFiring
{
}
state NormalFire
{
}

///////////////////////////////////////////////////////////////////////////////
// Default properties
///////////////////////////////////////////////////////////////////////////////

defaultproperties
{
     SPAccuracy=1.400000
     CatMesh=SkeletalMesh'MP_Weapons.MP_LS_ShotgunCat'
     MFBloodTexture=Texture'nathans.muzzleflashes.bloodmuzzleflash'
     StartShotsWithCat=9
     CatFireSound=Sound'WeaponSounds.shotgun_catfire'
     CatSkinIndex=2
     ViolenceRank=3
     RecognitionDist=1100.000000
     ShotCountMaxForNotify=10
     AI_BurstCountMin=3
     holdstyle=WEAPONHOLDSTYLE_Double
     switchstyle=WEAPONHOLDSTYLE_Double
     firingstyle=WEAPONHOLDSTYLE_Double
     MinRange=200.000000
     ShakeOffsetTime=2.500000
     CombatRating=4.000000
     FirstPersonMeshSuffix="Shotgun"
     WeaponSpeedLoad=1.500000
     WeaponSpeedHolster=1.500000
     WeaponSpeedShoot1Rand=0.300000
     WeaponSpeedIdle=0.800000
     AmmoName=Class'Ig50Inventory.ShotgunIg50AmmoInv'
     AutoSwitchPriority=3
     ShakeRotMag=(X=400.000000)
     ShakeRotTime=2.500000
     ShakeOffsetMag=(X=20.000000,Y=4.000000,Z=4.000000)
     TraceAccuracy=0.700000
     aimerror=400.000000
     AIRating=0.300000
     MaxRange=512.000000
     FireSound(0)=Sound'WeaponSounds.shotgun_fire'
     FlashOffsetY=-0.050000
     FlashOffsetX=0.060000
     FlashLength=0.050000
     MuzzleFlashSize=128.000000
     MFTexture=Texture'Timb.muzzle_flash.shotgun_corona'
     bDrawMuzzleFlash=True
     MuzzleFlashScale=2.400000
     MuzzleFlashStyle=STY_Normal
     InventoryGroup=3
     GroupOffset=3
     PickupClass=Class'Ig50Inventory.ShotgunIg50Pickup'
     BobDamping=0.975000
     AttachmentClass=Class'Ig50Inventory.ShotgunIg50Attachment'
     ItemName="Shotgun Ig50"
     Mesh=SkeletalMesh'MP_Weapons.MP_LS_Shotgun'
     Skins(0)=Texture'MP_FPArms.LS_arms.LS_hands_dude'
     Skins(1)=Texture'Ig50Tex.ShotgunIg50_timb'
     Skins(2)=Texture'AnimalSkins.Cat_Orange'
     Skins(3)=Texture'AnimalSkins.Cat_Orange'
     SoundRadius=255.000000
}
