///////////////////////////////////////////////////////////////////////////
// Feeder that attaches to other objects to be poured out (like a gas tank)
///////////////////////////////////////////////////////////////////////////
class UrinePourFeeder extends FluidPourFeeder;

var Actor CurrentSteamAttach;			// The current thing the steam is attached to
var float	Damage;
var class<DamageType> BodyDamage;

const VEL_Z_DOT_PLUS = 20;
const FLIP_TIME = 2;
const VARY_INTERP_TIME=0.2;
const PLAYER_PUT_OUT	=	0.05;
const PAWN_PUT_OUT		=	0.05;

const MIN_USE_RAD						=	10;

///////////////////////////////////////////////////////////////////////////
// The fluid is hitting a pawn. 
///////////////////////////////////////////////////////////////////////////
function HittingPawn(FPSPawn fpawn, vector HitLocation)
{
	local LambController lambc;

	lambc = LambController(fpawn.Controller);

	// Only happens if guy is still alive
	if(lambc != None)
	{
		// Set me to dripping in pee
		lambc.HitWithFluid(MyType, HitLocation);

		lambc.BodyJuiceSquirtedOnMe(P2Pawn(MyOwner), false);
	}

	if(fpawn.MyBodyFire != None)
	{
		MakeSteam();
		MySteam.SetLocation(HitLocation);

		// Put out the fire
		fpawn.MyBodyFire.TakeDamage
		(
			PAWN_PUT_OUT*Quantity,
			Pawn(MyOwner),
			HitLocation,
			vect(0, 0, 0),
			class'ExtinguishDamage'
		);
	}
}

///////////////////////////////////////////////////////////////////////////////
// Make steam for peeing out fires
///////////////////////////////////////////////////////////////////////////////
function MakeSteam()
{
	if(MySteam == None
		|| MySteam.GetStateName() == 'FinishingUp')
	{
		MySteam = spawn(class'SteamEmitter',MyOwner);
	}
	else
	{
		MySteam.Refresh();
		MySteam.SetBase(None);
	}
}

///////////////////////////////////////////////////////////////////////////
// Feeder hit an actor other than a puddle
// Check to see if you hit some fire
///////////////////////////////////////////////////////////////////////////
function int FeederHitActor(Actor Other, vector HitLocation, vector HitNormal,
						vector FeederStart, vector FeederEnd, float DeltaTime)
{
	if ( Other == None )
		return 0;

	if (Other.bStatic)//Other.bWorldGeometry ) 
	{
	}
	else 
	{
		Other.TakeDamage(Damage*50, Pawn(Owner), HitLocation, vect(0, 0, 0), Class'Ig50Inventory.UrineCutterDamage');
	}

}

///////////////////////////////////////////////////////////////////////////
// Manually check if you're hitting you're owner, since Trace won't let you
// and we can do it more cheaply. 
// Trace checks to not hit the owner, and besides, we don't need that
// sort of accurate collision for this
// Do this by checking direction of pouring
// This is merely for DETECTION of the collision, not for the splashing and all
///////////////////////////////////////////////////////////////////////////
function HittingOwner(vector Dir)
{
	local LambController lambc;
	local P2Player pplayer;
		
	local P2Pawn p2p;
	local vector toppos;

	p2p = P2Pawn(Owner);

	if(p2p != None)
	{
		// If it's getting poured/pushed upwards, then it's going to fall back
		// down and hit the owner
		if(Dir.z > UpwardsZMin)
		{
			toppos = p2p.Location;
			toppos.z += p2p.CollisionRadius;

			lambc = LambController(p2p.Controller);
			if(LambController(p2p.Controller) != None)
				HittingPawn(p2p, toppos);
			else
			{
				pplayer = P2Player(p2p.Controller);
				if(pplayer != None)
				{
					// Only let the pee hit him in the face if he's been 
					// peeing long enough for a stream to hit him, *or* let
					// it hit him immediately if he's on fire (to put him out quicker)
					if(bFullyActive
						|| p2p.MyBodyFire != None)
						pplayer.PissedOnHimself();

					if(p2p.MyBodyFire != None)
					{
						// Stick the steam on the dude.
						MakeSteam();
						CurrentSteamAttach = p2p;
						MySteam.SetBase(CurrentSteamAttach);

						// Put out the fire
						p2p.MyBodyFire.TakeDamage
						(
							PLAYER_PUT_OUT*Quantity,
							Pawn(MyOwner),
							p2p.Location,
							vect(0, 0, 0),
							class'ExtinguishDamage'
						);
					}
				}
			}
		}
	}
}

///////////////////////////////////////////////////////////////////////////////
// Check for collisions and move particles
///////////////////////////////////////////////////////////////////////////////
function SetStartSpeeds(float SpeedBase, float RealLife, optional vector StartRotationOffset)
{
}

///////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////
function VaryStream(float DeltaTime)
{
	// STUB OUT to not do this anymore for the urine
}

///////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////
function Timer()
{
	// STUB OUT
	//AdjustLighting();
}

defaultproperties
{
     InitialPourSpeed=600.000000
     InitialSpeedZPlus=500.000000
     UpwardsZMin=0.900000
     bCanHitActors=True
     SpawnDripTime=0.150000
     QuantityPerHit=10.000000
     MomentumTransfer=10.000000
     Damage=50.000000
     SplashClass=Class'FX.UrineSplashEmitter'
     TrailClass=Class'FX.UrineTrail'
     TrailStarterClass=Class'FX.UrineTrailStarter'
     PuddleClass=Class'FX.UrinePuddle'
     MyDamageType=Class'Ig50Inventory.UrineCutterDamage'
     MyType=FLUID_TYPE_Urine
     Quantity=40.000000
     Begin Object Class=StripEmitter Name=StripEmitter27
         Acceleration=(Z=-2000.000000)
         UseColorScale=True
         ColorScale(0)=(Color=(B=128,G=255,R=255))
         ColorScale(1)=(RelativeTime=1.000000,Color=(G=255,R=255))
         FadeOut=True
         FadeInEndTime=0.300000
         FadeIn=True
         MaxParticles=17
         UseSizeScale=True
         UseRegularSizeScale=False
         SizeScale(0)=(RelativeSize=1.000000)
         SizeScaleRepeats=3.000000
         StartSizeRange=(X=(Min=0.500000,Max=2.500000))
         DrawStyle=PTDS_Brighten
         Texture=Texture'nathans.Skins.pour1'
         SecondsBeforeInactive=0.000000
         LifetimeRange=(Min=0.500000,Max=0.500000)
         StartVelocityRange=(X=(Min=-1000.000000,Max=-1000.000000),Z=(Min=300.000000,Max=300.000000))
         Name="StripEmitter27"
     End Object
     Emitters(0)=StripEmitter'FX.StripEmitter27'
     Begin Object Class=SpriteEmitter Name=SpriteEmitter171
         Acceleration=(Z=-1800.000000)
         UseColorScale=True
         ColorScale(0)=(Color=(B=128,G=255,R=255))
         ColorScale(1)=(RelativeTime=1.000000,Color=(G=255,R=255))
         FadeOutStartTime=1.100000
         FadeOut=True
         MaxParticles=25
         SpinParticles=True
         SpinsPerSecondRange=(X=(Min=0.200000,Max=0.500000))
         UseSizeScale=True
         UseRegularSizeScale=False
         SizeScale(1)=(RelativeTime=0.600000,RelativeSize=1.000000)
         SizeScale(2)=(RelativeTime=1.000000,RelativeSize=1.000000)
         StartSizeRange=(X=(Min=0.800000,Max=1.800000),Y=(Min=0.800000,Max=1.800000))
         DrawStyle=PTDS_Brighten
         Texture=Texture'nathans.Skins.drips1'
         TextureUSubdivisions=1
         TextureVSubdivisions=2
         UseRandomSubdivision=True
         SecondsBeforeInactive=0.000000
         LifetimeRange=(Min=1.300000,Max=1.600000)
         StartVelocityRange=(X=(Min=-20.000000,Max=20.000000),Y=(Min=150.000000,Max=150.000000),Z=(Min=200.000000,Max=200.000000))
         Name="SpriteEmitter171"
     End Object
     Emitters(1)=SpriteEmitter'FX.SpriteEmitter171'
     AutoDestroy=True
     bAlwaysRelevant=True
     RemoteRole=ROLE_SimulatedProxy
     bCollideActors=True
}
